THE BOOST MPL LIBRARY: Resources

Front Page / Resources

# Resources

For those of you whose interest in metaprogramming is not fully satisfied by this documentation, we've collected a few references to other resources that we think you are likely to fancy. Most notably, a book named "C++ Template Metaprogramming: Concepts, Tools, and Techniques from Boost and Beyond" by David Abrahams and Aleksey Gurtovoy is considered to be the most authoritative and up-do-date treatment of the subject as of today. The tutorial included with this documentation is in fact an excerpt from this work.

Other notable book resources include Andrei Alexandrescu's "Modern C++ Design: Generic Programming and Design Patterns Applied", in which Andrei explorers the appication of C++ metaprogramming techniques to implementing highly reusable and configurable generic designs, and "C++ Templates - The Complete Guide", by David Vandevoorde and Nicolai M. Josuttis — the book on the details and workings of the C++ template system.

We can also recommend a number online resources:

- Todd L. Veldhuizen, "Using C++ template metaprograms", C++ Report Vol. 7 No. 4 (May 1995), pp. 36-43.
- Todd L. Veldhuizen and Dennis Gannon, "Active Libraries: Rethinking the roles of compilers and libraries", SIAM Workshop on Object Oriented Methods for Inter-operable Scientific and Engineering Computing, October 21-23, 1998
- Todd L. Veldhuizen, "C++ Templates as Partial Evaluation", 1999 ACM SIGPLAN Workshop on Partial Evaluation and Semantics-Based Program Manipulation (PEPM'99).

Finally, if you come accross a high-quality, notable work on the topic that you think should be listed here, please let us know!